# stockDL
A financial deep learning library for stocks price prediction and comparison with traditional investment strategies. The Library is based on LSTM-Neural Networks and Conv1D + LSTM Neural Networks. STRICTLY FOR EDUCATIONAL PURPOSES.
